==> Paws-0.15.tar.gz: Paws-0.15/lib/Paws/OpsWorks/DetachElasticLoadBalancer.pm <==

package Paws::OpsWorks::DetachElasticLoadBalancer;
  use Moose;
  has ElasticLoadBalancerName => (is => 'ro', isa => 'Str', required => 1);
  has LayerId => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DetachElasticLoadBalancer');
  class_has _returns => (isa => 'Str', is => 'ro');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::OpsWorks::DetachElasticLoadBalancer - Arguments for method DetachElasticLoadBalancer on Paws::OpsWorks

=head1 DESCRIPTION

This class represents the parameters used for calling the method DetachElasticLoadBalancer on the 
AWS OpsWorks service. Use the attributes of this class
as arguments to method DetachElasticLoadBalancer.

You shouln't make instances of this class. Each attribute should be used as a named argument in the call to DetachElasticLoadBalancer.

As an example:

  $service_obj->DetachElasticLoadBalancer(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES

=head2 B<REQUIRED> ElasticLoadBalancerName => Str

  

The Elastic Load Balancing instance's name.










=head2 B<REQUIRED> LayerId => Str

  

The ID of the layer that the Elastic Load Balancing instance is
attached to.












=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DetachElasticLoadBalancer in L<Paws::OpsWorks>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.18.tar.gz: Paws-0.18/lib/Paws/OpsWorks/DetachElasticLoadBalancer.pm <==

package Paws::OpsWorks::DetachElasticLoadBalancer;
  use Moose;
  has ElasticLoadBalancerName => (is => 'ro', isa => 'Str', required => 1);
  has LayerId => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DetachElasticLoadBalancer');
  class_has _returns => (isa => 'Str', is => 'ro');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::OpsWorks::DetachElasticLoadBalancer - Arguments for method DetachElasticLoadBalancer on Paws::OpsWorks

=head1 DESCRIPTION

This class represents the parameters used for calling the method DetachElasticLoadBalancer on the 
AWS OpsWorks service. Use the attributes of this class
as arguments to method DetachElasticLoadBalancer.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DetachElasticLoadBalancer.

As an example:

  $service_obj->DetachElasticLoadBalancer(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES

=head2 B<REQUIRED> ElasticLoadBalancerName => Str

  The Elastic Load Balancing instance's name.

=head2 B<REQUIRED> LayerId => Str

  The ID of the layer that the Elastic Load Balancing instance is
attached to.



=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DetachElasticLoadBalancer in L<Paws::OpsWorks>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut
